"""
  BA_SpiderPaint_v2c_QT2

  updated for GMIC version QT 2.

  Filter to create a number of 'plasmatic web' layers
  from which a nice image may be created.
  Based on one of Lylejk's flows from Gimp Chat.
  Thank you Lyle!
  Written by Brian Andersen (animicule@gimpchat.com)
  April 2017  
  Name by Dinasset from Gimp Chat
  Filter Dependent upon GMIC vers 2.0.0QT
  May or may not work using any other known version of GMIC.
  Filter developed on Windows 7 64bit and Gimp Version 2.8.16

 You should have received a copy of the GNU General Public License
 along with this program if not, you can view the GNU General Public
 License version 3 at the web site http://www.gnu.org/licenses/gpl-3.0.html
 Alternatively you can write to the Free Software Foundation, Inc., 675 Mass
 Ave, Cambridge, MA 02139, USA.
"""
#!/usr/bin/env python
from gimpfu import *
import decimal
import sys

######################
# INTERNAL FUNCTIONS #  
######################

def Decode_A_Layer (LayerString):
#  LayerID     #CreateY/F/N x boost 0-3 x Solidify 0-35 x Scale% 1-200.0 x Noise .01-20.0 x SegLen .5-15.0 x Morph 0-10
#   1 LS[0]      2 LS[1]     3 LS[2]      4 LS[3]        5 LS[4]           6 LS[5]          7 LS[6]      8 LS[7]
#global LS, makeLayer, docutout, boost, solidifyOption, layerScale, squiggleNoise, segmentLength, morphAmount

    global makeLayer, docutout, boost, solidifyOption, layerScale, squiggleNoise, segmentLength, morphAmount
    docutout = False
    LS = LayerString.strip() #removes newline chr from string just in case
    LS = LS.lower()
    LS = LS.replace(' ','')
    count_x = LS.count('x')
    LS = LS.split('x')
    if LS[1] != 'n':    ## if not creating layer don't return error on unused string
        if count_x < 7: 
            pdb.gimp_message('Command string min 8 values w/ 7 "x" separators. Line#'+' '+str(LS[0]))
            sys.exit()
        if count_x > 7:
            pdb.gimp_message('count_x>8 Exit'+str(count_x)+' Line#'+' '+str(LS[0]))
            sys.exit()       
        if len(LS) < 8:
            pdb.gimp_message('Command less than minimum 8 values. Exit'+' Line#'+' '+str(LS[0]))
            sys.exit()
        if len(LS) > 8:
            pdb.gimp_message('LS > 8 :'+str(len(LS))+' Line#'+' '+str(LS[0]))
            sys.exit()
##-------------------
    #global makeLayer
    if LS[1] == 'n' :
        makeLayer = False
        return makeLayer
    elif LS[1] == 'y':
        makeLayer = True
        docutout  = True
    elif LS[1] == 'f':
        makeLayer = True
        docutout  = False
    else:
        pdb.gimp_message('CREATE option not N,D,or Y'+' Line#'+' '+str(LS[0])+' '+str(LS[1]))
        sys.exit()
##-------------------
    #global boost / desat
    if int(LS[2])   == 0:
        boost = 0 # default
    elif int(LS[2]) == 1:
        boost = 1 # boost 
    elif int(LS[2]) == 2:
        boost = 2 # deSat
    elif int(LS[2]) == 3:
        boost = 3 # white to alpha
    elif int(LS[2]) == 4:
        boost = 4 # boost and white to alpha
    else:
        pdb.gimp_message('BOOST/DESAT option entry not 0-4'+' Line#'+' '+str(LS[0])+' '+str(LS[2]))
        sys.exit()
##-------------------
    #global solidifyOption
    if not -1 < int(LS[3]) < 36:
        pdb.gimp_message('LS[3] solidifyOption not 0 to 35'+' Line#'+' '+str(LS[0])+' '+str(LS[3]))
        sys.exit()
    else:
        solidifyOption = int(LS[3])
##-------------------
    #global layerScale
    if int(LS[4]) == 0.0:
        layerScale = 1
    elif not 1.0 < float(LS[4]) < 201.0:
        pdb.gimp_message('LS[4] layerScale not 1-200'+' Line#'+' '+str(LS[0])+' '+str(LS[4]))
        sys.exit()
    else:
        layerScale = float(LS[4])/100.0
##-------------------
    #global squiggleNoise
    if not -.01 < float(LS[5]) < 20.01:
        pdb.gimp_message('LS[5] squiggleNoise not 0.0-20.00'+' Line#'+' '+str(LS[0])+' '+str(LS[5]))
        sys.exit()
    else:
        squiggleNoise = float(LS[5])
##-------------------
    #global segmentLength
    if not 0.4999 < float(LS[6]) < 15.01:
        pdb.gimp_message('LS[6] segmentLength not 0.5-15.0'+' Line#'+' '+str(LS[0])+' '+str(LS[6]))
        sys.exit()
    else:
        segmentLength = float(LS[6])
##-------------------
    #global morphAmount
    if not -1 < int(LS[7]) < 11:
        pdb.gimp_message('LS[7] morphAmount not 0-10'+' Line#'+' '+str(LS[0])+' '+str(LS[7]))
        sys.exit()
    else:
        morphAmount = int(LS[7])
##-------------------
    return makeLayer, docutout, boost, solidifyOption, layerScale, squiggleNoise, segmentLength, morphAmount
### END FUNCTION DECODE_A_LAYER <<<<----------------------------------------------- 

def Solidify_A_Layer(solidifyOption,worklayer):
    if not 0 < solidifyOption < 36:
        pdb.gimp_message('Solidify Option not 1 to 35'+' Line#'+' '+str(LS[0]))
        return()                               
    if solidifyOption   ==  1:   
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 50,1,0,0,0")     
    elif solidifyOption ==  2:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 70,1,0,-2,0") # was -2 now 0<< always used for stitched BG    
    elif solidifyOption ==  3:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 50,2,0,-1,0")    
    elif solidifyOption ==  4:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 40,1,30,1,0")   
    elif solidifyOption ==  5:  
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 75,1,20,4,0")  
    elif solidifyOption ==  6:                         
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 30,2,45,1,0")  
    elif solidifyOption ==  7:                         
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 35,0,20,0,0")   
    elif solidifyOption ==  8:     
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 70,1,65,0,0") 
    elif solidifyOption ==  9:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 27,2,76,0,0")   
    elif solidifyOption == 10:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 50,0,0,3,0")  
    elif solidifyOption == 11:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 15,0,0,1,0")
    elif solidifyOption == 12:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 20,1,0,1,0")
    elif solidifyOption == 13:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 25,2,0,1,0")
    elif solidifyOption == 14:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 45,1,76,1,0")
    elif solidifyOption == 15:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 27,2,76,1,0")
    elif solidifyOption == 16:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 70,1,100,0,0")
    elif solidifyOption == 17:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 70,2,100,0,0")
    elif solidifyOption == 18:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 20,0,100,-3,0")
    elif solidifyOption == 19:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 35,1,20,1,0")
    elif solidifyOption == 20:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 50,0,50,-3,0") 
    elif solidifyOption == 21:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 56,1,57,-6,0") 
    elif solidifyOption == 22:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 27,2,76,5,0")
    elif solidifyOption == 23:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 70,1,30,0,0")
    elif solidifyOption == 24:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 70,1,3,0,0") 
    elif solidifyOption == 25:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 70,1,0,0,0") 
    elif solidifyOption == 26:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 70,1,0,-3,0")
    elif solidifyOption == 27:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 70,1,25,3,0")
    elif solidifyOption == 28:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 20,0,100,0,0")
    elif solidifyOption == 29:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 20,0,100,3,0")
    elif solidifyOption == 30:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 65,0,20,10,0")
    elif solidifyOption == 31:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 65,1,20,10,0")
    elif solidifyOption == 32:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 75,2,20,10,0")
    elif solidifyOption == 33:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 65,0,100,10,0")
    elif solidifyOption == 34:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 65,1,100,10,0")
    elif solidifyOption == 35:
        pdb.plug_in_gmic_qt(newImage, worklayer,1,0,  "-v - -fx_solidify_td 75,2,100,10,0")
### END FUNCTION Solidify_A_Layer <<<<------------------------------------------- 

def Intensify_Custom(workLay, customIntensity):
    iCnt=0
    while iCnt < customIntensity:
        TMPLay = workLay.copy()
        TMPLay.opacity = 100.0 
        TMPLay.mode = SCREEN_MODE
        iCnt+=1         
        newImage.add_layer(TMPLay, 0)
        pdb.gimp_item_set_visible(TMPLay, True)
### END FUNCTION Intensify_Custom <<<<-------------------------------------------

def Intensify_inTens(workLay, inTens):
    iCnt=0
    while iCnt < inTens:
        TMPLay = workLay.copy()
        TMPLay.opacity = 100.0 
        TMPLay.mode = SCREEN_MODE
        iCnt+=1         
        newImage.add_layer(TMPLay, 0)
        pdb.gimp_item_set_visible(TMPLay, True)
### END FUNCTION Intensify_inTens <<<<-------------------------------------------

##################
# MAIN FUNCTION ######################################################
##################        

def BA_SpiderPaint_v2c_qt2(inImage, inDrawable, worklen, inTens, lay1str, lay2str, lay3str, lay4str, lay5str, lay6str, lay7str, lay8str, smokey, lay10str, stitched, addbub, ) :

    pdb.gimp_context_push()
    currFG    = pdb.gimp_context_get_foreground()
    currBG    = pdb.gimp_context_get_background()
    outwidth  = inImage.width
    outheight = inImage.height
    coltype   = inImage.base_type
 
    oriname = inDrawable.name
    if '.' in oriname:
        prefix = oriname.split(".", 1)
        oriname = prefix[0]
    suffix = ",BA_SpiderPaint2c"

    global newImage
    pdb.gimp_context_set_interpolation(INTERPOLATION_LANCZOS)

    out1=out2=out3=out4=out5=out6=out7=out8=out9=out10=out20=out1a=False

    white = "#ffffff"  # for use in color to alpha
    black = "#000000"  # for use in cut black

    if outwidth > outheight:
        workScale = decimal.Decimal(worklen)/decimal.Decimal(outwidth)
    else:
        workScale = decimal.Decimal(worklen)/decimal.Decimal(outheight)
    workwidth  =int(outwidth *workScale)  
    workheight =int(outheight*workScale)  

####### create newImage at output size and bring in subject layer
    newImage = pdb.gimp_image_new(outwidth, outheight, coltype)     
    oriSUB   = pdb.gimp_layer_new_from_drawable(inDrawable, newImage)     #save subject layer
    oriSUB.mode = NORMAL_MODE
    oriSUB.name = oriname+suffix
    oriSUB.opacity = 100.0 
    newImage.add_layer (oriSUB, 0)
    pdb.gimp_item_set_visible(oriSUB, False)
    alpha=pdb.gimp_drawable_has_alpha(oriSUB)
    if not alpha:
        #pdb.gimp_layer_add_alpha (oriSUB)    #  RGBA
        ####### if no alpha layer, no transparency so subject not isolated - end run
        pdb.gimp_message('Subject must be "extracted" with transparent background.\n Script ended Normally')
        return()
####### create padlayer at max possible size.
    if outwidth >= workwidth:
        padLayer = pdb.gimp_layer_new(newImage,outwidth*2,outheight*2,coltype,'pad layer',100.0,NORMAL_MODE)
    else:
        padLayer = pdb.gimp_layer_new(newImage,workwidth*2,workheight*2,coltype,'pad layer',100.0,NORMAL_MODE)
    pdb.gimp_layer_set_offsets(padLayer,0,0) 
    newImage.add_layer(padLayer, 1)  
    pdb.gimp_context_set_foreground(black)
    pdb.gimp_drawable_fill(padLayer,0)
    pdb.gimp_item_set_visible(padLayer,False)

#################################################################################################
####### Layer 1 Razorsplit Background with Intensity and Stitched Background ####################
#################################################################################################

    if stitched != 0:  # force creation of lay1 if stitched bg is requested.
        lsx = lay1str.lower()
        lsx = lsx.replace(' ','')
        if lsx[0] == 'n':  # now edit lay1str
            lay1str = 'y'+ lsx[1:]
    LayerString = '1x'+lay1str
    Decode_A_Layer(LayerString)
    if makeLayer:  
        out1 = True
        lay1 = oriSUB.copy()
        lay1.mode = NORMAL_MODE
        lay1.name = "RazorSplit BG"
        newImage.add_layer(lay1, 0)
        lay1.opacity = 100.0 
        pdb.gimp_item_set_visible(lay1, False)
# scale with layerScale from LayerString ###### Lay1 special layerScale against workwidth not output width 
        pdb.gimp_layer_scale_full(lay1,(workwidth*layerScale),(workheight*layerScale), True,3) # True = local origin, 3=Lanczos
        pdb.gimp_layer_set_offsets(lay1,0,0) # after scale, re-position layer.
# solidify at low scale
        if solidifyOption > 0:
            Solidify_A_Layer(solidifyOption,lay1)
# enhance option
        if boost == 1 or boost == 4:    #boost =1 desat =2 neither = 0
            pdb.plug_in_gmic_qt(newImage, lay1,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0")
        if boost == 2: 
            pdb.gimp_desaturate_full(lay1,2)
        if boost == 3 or boost == 4: 
            pdb.plug_in_colortoalpha(newImage, lay1, white)
# squiggle highlight 
        pdb.plug_in_gmic_qt(newImage, lay1,1,0,  # 1=input only active layer 
        "-v - -fx_Squiggly "+str(squiggleNoise)+","+str(segmentLength)+",4,0,.7,0,0,0,3,0.2,0.4,12,1,1,0")
# scale to worksize (worksize) if layerScale != workScale
        pdb.gimp_layer_scale(lay1,workwidth,workheight,False)
        pdb.gimp_layer_set_offsets(lay1,0,0) # after scale, re-position layer.
# morph at normal worksize
        pdb.plug_in_gmic_qt(newImage, lay1,1,0,  # 1=input only active layer 
        '-v - -fx_morpho_v2 0,0,'+str(morphAmount)+','+'"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
# intensify custom
        pdb.gimp_item_set_visible(lay1,True)
        Intensify_Custom(lay1,40)
        lay1 = pdb.gimp_image_merge_visible_layers(newImage, 0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay1,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay1,0,0) # after scale, re-position layer.
# cut black 
        pdb.gimp_image_select_color(newImage,0,lay1, black)
        pdb.gimp_edit_cut(lay1)
        pdb.gimp_selection_none(newImage)
# razor cut
        pdb.gimp_image_select_item(newImage,0,lay1)
        pdb.gimp_selection_shrink(newImage,1)
        pdb.gimp_edit_cut(lay1)
# check for all black subject
        non_empty, x1, y1, x2, y2 = pdb.gimp_selection_bounds(newImage)
        pdb.gimp_selection_none(newImage)
        if not non_empty:
            pdb.gimp_message('CAN NOT USE ALL BLACK SUBJECT-\nOr Morph Setting too High on Layer 1')
        pdb.gimp_selection_none(newImage)
# cutout subject leaving background only - NOTE - 'no cut' option not offered on layer 1 
        pdb.gimp_image_select_item(newImage, 0, oriSUB)
        pdb.gimp_edit_cut(lay1)
        pdb.gimp_selection_none(newImage)
        lay1.mode = SCREEN_MODE
        lay1.opacity = 20.0
        pdb.gimp_item_set_visible(lay1,False)
###################################################
####### Layer 1A - Stitched Background Layer   #######
###################################################
    if stitched != 0: 
        out1a = True
        lay1a = lay1.copy()
        lay1a.mode = NORMAL_MODE
        newImage.add_layer(lay1a, 0)
        #using #2 with good result - could make var (changed -2 to -1 in solidy 2 4/25/17)
        Solidify_A_Layer(2,lay1a)        
        if stitched == 1:
            lay1a.name = "Stitched,full"
        if stitched == 2:
            pdb.plug_in_gmic_qt(newImage, lay1a,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0") 
            lay1a.name = "Stitched,full,boosted"
        if stitched == 3:
            pdb.plug_in_colortoalpha(newImage, lay1a, white) 
            lay1a.name = "Stitched,full,no white"
        if stitched == 4:
            pdb.plug_in_gmic_qt(newImage, lay1a,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0") 
            pdb.plug_in_colortoalpha(newImage, lay1a, white) 
            lay1a.name = "Stitched,full,boosted, no white"
        if stitched == 5:
            pdb.gimp_image_select_item(newImage, 0, oriSUB)
            pdb.gimp_edit_cut(lay1a)
            pdb.gimp_selection_none(newImage)
            lay1a.name = "Stitched,cut"
        if stitched == 6:
            pdb.gimp_image_select_item(newImage, 0, oriSUB)
            pdb.gimp_edit_cut(lay1a)
            pdb.gimp_selection_none(newImage)
            pdb.plug_in_gmic_qt(newImage, lay1a,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0")
            lay1a.name = "Stitched,cut,boosted"
        if stitched == 7:
            pdb.gimp_image_select_item(newImage, 0, oriSUB)
            pdb.gimp_edit_cut(lay1a)
            pdb.gimp_selection_none(newImage)
            pdb.plug_in_colortoalpha(newImage, lay1a, white)
            lay1a.name = "Stitched,cut,no white"
        if stitched == 8:
            pdb.gimp_image_select_item(newImage, 0, oriSUB)
            pdb.gimp_edit_cut(lay1a)
            pdb.gimp_selection_none(newImage)
            pdb.plug_in_gmic_qt(newImage, lay1a,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0")
            pdb.plug_in_colortoalpha(newImage, lay1a, white)
            lay1a.name = "Stitched,cut,boosted,no white"
        if stitched == 9:
            remlay1a = lay1a.copy()
            newImage.add_layer(remlay1a)
            remlay1a.mode = NORMAL_MODE
            remlay1a.name = 'recycle Layer1a' #keeping object lay1a name after new from visible
            pdb.gimp_image_remove_layer(newImage, lay1a)
            pdb.gimp_image_select_item(newImage, 0, oriSUB)
            pdb.gimp_edit_cut(remlay1a)  
            pdb.gimp_selection_none(newImage)
            tempoLay = remlay1a.copy()
            tempoLay.mode = NORMAL_MODE
            tempoLay.name = "tempoLay"
            tempoLay.opacity = 100.0 
            newImage.add_layer(tempoLay, 0)
            pdb.gimp_item_set_visible(tempoLay, True)   
            bilatLay = remlay1a.copy()
            bilatLay.mode = NORMAL_MODE
            bilatLay.name = "bilatLay"
            bilatLay.opacity = 100.0 
            newImage.add_layer(bilatLay, 0)
            pdb.gimp_item_set_visible(bilatLay, True)
            pdb.plug_in_gmic_qt(newImage, bilatLay,1,0,  # 1=input only active layer
            "-v - -fx_smooth_bilateral 10,12,2,0,0") #v179
            #v176 "-v - -fx_bilateral 10,12,2,0,0")
            bilatLay.mode = GRAIN_EXTRACT_MODE
            mergeLay=pdb.gimp_image_merge_down(newImage, bilatLay, 0)
            mergeLay.name = "mergeLay"    
            intensityCnt=0
            while intensityCnt < 6:
                TMPLayer = 'merge'+str(intensityCnt)  
                TMPLayer = mergeLay.copy()
                TMPLayer.mode = GRAIN_MERGE_MODE
                TMPLayer.opacity = 100.0 
                newImage.add_layer(TMPLayer, 0)
                pdb.gimp_item_set_visible(TMPLayer, True)
                intensityCnt=intensityCnt+1
            pdb.gimp_item_set_visible(remlay1a, False)
            convoLay=pdb.gimp_image_merge_visible_layers(newImage, 0)
            convoLay.mode = GRAIN_MERGE_MODE
            convoLay.name = "convoLay"
            convoLay.opacity = 100.0
            pdb.plug_in_gmic_qt(newImage, convoLay,1,0,  # 1=input only active layer
            "-v - -fx_smooth_anisotropic 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0") #v179
            #v176 "-v - -fx_anisotropic_smoothing 150,0.42,0.85,0.6,7.83,0.68,19.07,2.64,0,1,1,0,0")
            convoLay = pdb.gimp_image_get_active_layer(newImage)
            pdb.plug_in_gmic_qt(newImage, convoLay,1,0,  # 1=input only active layer
            "-v - -fx_freaky_details 3,12.6697,3,22,0,151,0")
            convoLay.name = "convoLay" 
            temp2 = remlay1a.copy()
            temp2.mode = HUE_MODE
            temp2.name = "temp2"
            temp2.opacity = 100.0 
            newImage.add_layer(temp2, 0)
            pdb.gimp_item_set_visible(temp2, True)   
            pdb.gimp_item_set_visible(remlay1a, True)
            visONE = pdb.gimp_layer_new_from_visible(newImage,newImage, 'Visible Color')
            newImage.add_layer(visONE, 0) 
            visONE.mode = COLOR_MODE
            visONE.opacity = 100.0
            pdb.gimp_item_set_visible(visONE, True)
            fdLay = visONE.copy()
            fdLay.mode = SOFTLIGHT_MODE
            fdLay.name = 'fdLay'
            fdLay.opacity  = 100.0
            newImage.add_layer(fdLay)
            pdb.gimp_item_set_visible(fdLay, True)
            pdb.plug_in_gmic_qt(newImage, fdLay,1,0,  # 1=input only active layer
            "-v - -fx_freaky_details 2,10,1,11,0,32,0")
            pdb.gimp_item_set_visible(fdLay, True)
            hbLay = fdLay.copy()
            hbLay.mode = MULTIPLY_MODE
            hbLay.name = 'hblay'
            hbLay.opacity = 100.0
            newImage.add_layer(hbLay)
            pdb.gimp_item_set_visible(hbLay, True)
            pdb.plug_in_gmic_qt(newImage, hbLay,1,0,  # 1=input only active layer
            "-v - -fx_highlight_bloom 90,60,60,30,20,0")
            pdb.gimp_item_set_visible(padLayer, True)
            visTwo = pdb.gimp_layer_new_from_visible(newImage,newImage, 'visTwo')
            newImage.add_layer(visTwo, 0) 
            visTwo.mode = SCREEN_MODE
            visTwo.opacity = 100.0
            lay1a = pdb.gimp_layer_new_from_visible(newImage,newImage, 'Stitched Exaggerated')
            newImage.add_layer(lay1a)
            lay1a.mode = NORMAL_MODE
            lay1a.opacity  = 35.0
# remove temp layers 
            pdb.gimp_item_set_visible(padLayer, False)
            pdb.gimp_image_remove_layer(newImage, visTwo)
            pdb.gimp_image_remove_layer(newImage, hbLay)
            pdb.gimp_image_remove_layer(newImage, fdLay)
            pdb.gimp_image_remove_layer(newImage, visONE)
            pdb.gimp_image_remove_layer(newImage, temp2)
            pdb.gimp_image_remove_layer(newImage, convoLay)
            pdb.gimp_image_remove_layer(newImage, remlay1a)
# move lay1 above stitched layer in stack            
        pdb.gimp_image_raise_item(newImage, lay1)
# done - set stitched
        lay1a.mode = SCREEN_MODE
        lay1a.opacity = 35.0
        pdb.gimp_item_set_visible(lay1a, False)

#################################################################################################
####### Layer 2 - Low Intensity Background or Full   ############################################ 
#################################################################################################

    LayerString = '2x'+lay2str
    Decode_A_Layer(LayerString)
    if makeLayer:
        layname = "Low Intensity "
        if docutout:
            layname = layname+"BG"
        else:
            layname = layname+"Full"
        out2 = True
        lay2 = oriSUB.copy()
        lay2.mode = NORMAL_MODE
        lay2.name = layname
        lay2.opacity = 100.0 
        newImage.add_layer(lay2, 0)
        pdb.gimp_item_set_visible(lay2, False)
# scale with layerScale from LayerString
        if layerScale != workScale:
            pdb.gimp_layer_scale_full(lay2,(workwidth*layerScale),(workheight*layerScale), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay2,0,0) # after scale, re-position layer.
# solidify
        if solidifyOption > 0:
            Solidify_A_Layer(solidifyOption,lay2)
# enhance option
        if boost == 1 or boost == 4:    #boost =1 desat =2 neither = 0
            pdb.plug_in_gmic_qt(newImage, lay2,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0")
            layname = layname+",boost"
        if boost == 2: 
            pdb.gimp_desaturate_full(lay2,2)
            layname = layname+",desat"
        if boost == 3 or boost == 4: 
            pdb.plug_in_colortoalpha(newImage, lay2, white)
            layname = layname+",nowhite"
# squiggle highlight at low scale
        pdb.plug_in_gmic_qt(newImage, lay2,1,0,  # 1=input only active layer 
        "-v - -fx_Squiggly "+str(squiggleNoise)+","+str(segmentLength)+",3.5,0,.6,0,0,0,3,0.2,0.4,12,1,1,0")
# scale to worksize (worksize) if layerScale != workScale
        if layerScale != workScale:
            pdb.gimp_layer_scale(lay2,workwidth,workheight,False)
            pdb.gimp_layer_set_offsets(lay2,0,0) # after scale, re-position layer.
# morph
        pdb.plug_in_gmic_qt(newImage, lay2,1,0,  # 1=input only active layer 
        '-v - -fx_morpho_v2 0,0,'+str(morphAmount)+','+'"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
# intensify custom
        pdb.gimp_item_set_visible(lay2,True)
        Intensify_Custom(lay2,5)
        lay2 = pdb.gimp_image_merge_visible_layers(newImage,0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay2,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay2,0,0) # after scale, re-position layer.
# cut black        
        pdb.gimp_image_select_color(newImage,0,lay2,black)
        pdb.gimp_edit_cut(lay2)
        pdb.gimp_selection_none(newImage)
# cutout subject leaving background only if selected
        if docutout:
            pdb.gimp_image_select_item(newImage, 0, oriSUB)
            pdb.gimp_edit_cut(lay2)
            pdb.gimp_selection_none(newImage)
# done - set 
        lay2.mode = SCREEN_MODE
        lay2.opacity = 20.0
        lay2.name = layname
        pdb.gimp_item_set_visible(lay2,False)
#################################################################################################
####### Layer 3 Highlight Layer with Intensity ##################################################
#################################################################################################

    LayerString = '3x'+lay3str
    Decode_A_Layer(LayerString)
    if makeLayer:
        layname = "HL Intense "
        if docutout:
            layname = layname+"BG"
        else:
            layname = layname+"Full"
        out3 = True
        lay3 = oriSUB.copy()
        lay3.mode = NORMAL_MODE
        lay3.name = layname
        lay3.opacity = 100.0 
        newImage.add_layer(lay3, 0)
        pdb.gimp_item_set_visible(lay3, False)
# scale with layerScale from LayerString
        if layerScale != workScale:
            pdb.gimp_layer_scale_full(lay3,(workwidth*layerScale),(workheight*layerScale), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay3,0,0) # after scale, re-position layer.
# solidify
        if solidifyOption > 0:
            Solidify_A_Layer(solidifyOption,lay3)
# enhance option
        if boost == 1 or boost == 4:    #boost =1 desat =2 neither = 0
            pdb.plug_in_gmic_qt(newImage, lay3,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0")
            layname = layname+",boost"
        if boost == 2: 
            pdb.gimp_desaturate_full(lay3,2)
            layname = layname+",desat"
        if boost == 3 or boost == 4: 
            pdb.plug_in_colortoalpha(newImage, lay3, white)
            layname = layname+",nowhite"
# squiggle
        pdb.plug_in_gmic_qt(newImage, lay3,1,0,  # 1=input only active layer 
        "-v - -fx_Squiggly "+str(squiggleNoise)+","+str(segmentLength)+",3.27,0,.5,0,0,0,3,0.2,0.4,12,1,1,0")
       # pdb.plug_in_gmic_qt(newImage, lay3,1,0,  # 1=input only active layer -- custom set for highlight 3
# scale to work size if layerScale != workScale
        if layerScale != workScale:
            pdb.gimp_layer_scale(lay3,workwidth,workheight,False)
            pdb.gimp_layer_set_offsets(lay3,0,0) # after scale, re-position layer.
# morph
        pdb.plug_in_gmic_qt(newImage, lay3,1,0,  # 1=input only active layer 
        '-v - -fx_morpho_v2 0,0,'+str(morphAmount)+','+'"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
        #pdb.plug_in_gmic_qt(newImage, lay3,1,0,  # 1=input only active layer
        #'-v - -fx_morpho_v2 0,0,'+str(morphAmount)+','+'"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
# intensify inTens
        pdb.gimp_item_set_visible(lay3,True)
        Intensify_inTens(lay3,inTens)
        lay3 = pdb.gimp_image_merge_visible_layers(newImage,0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay3,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay3,0,0) # after scale, re-position layer.
# cut black
        pdb.gimp_image_select_color(newImage,0,lay3,black)
        pdb.gimp_edit_cut(lay3)
        pdb.gimp_selection_none(newImage)
# cutout subject leaving background only if selected
        if docutout:
            pdb.gimp_image_select_item(newImage, 0, oriSUB)
            pdb.gimp_edit_cut(lay3)
            pdb.gimp_selection_none(newImage)
# done - set
        lay3.mode = SCREEN_MODE
        lay3.opacity = 35.0
        lay3.name = layname
        pdb.gimp_item_set_visible(lay3,False)

#################################################################################################
####### Layer 4  HL Layer Wide ##################################################################
#################################################################################################

    LayerString = '4x'+lay4str
    Decode_A_Layer(LayerString)
    if makeLayer:
        layname = "HL Wide "
        if docutout:
            layname = layname+"BG"
        else:
            layname = layname+"Full"
        out4 = True
        lay4 = oriSUB.copy()
        lay4.mode = NORMAL_MODE
        lay4.name = "HL Wide Intense"
        lay4.opacity = 100.0 
        newImage.add_layer(lay4, 0)
        pdb.gimp_item_set_visible(lay4, False)
# scale with layerScale from LayerString
        if layerScale != workScale:
            pdb.gimp_layer_scale_full(lay4,(workwidth*layerScale),(workheight*layerScale), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay4,0,0) # after scale, re-position layer.
# solidify
        if solidifyOption > 0:
            Solidify_A_Layer(solidifyOption,lay4)
# enhance option
        if boost == 1 or boost == 4:    #boost =1 desat =2 neither = 0
            pdb.plug_in_gmic_qt(newImage, lay4,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0")
            layname = layname+",boost"
        if boost == 2: 
            pdb.gimp_desaturate_full(lay4,2)
            layname = layname+",desat"
        if boost == 3 or boost == 4: 
            pdb.plug_in_colortoalpha(newImage, lay4, white)
            layname = layname+",nowhite"
# squiggle
        pdb.gimp_image_set_active_layer(newImage,lay4) # verify active for gmic call
        pdb.plug_in_gmic_qt(newImage, lay4,1,0,  # 1=input only active layer 
        "-v - -fx_Squiggly "+str(squiggleNoise)+","+str(segmentLength)+",3.27,0,.5,0,0,0,3,0.2,0.4,12,1,1,0")
# scale to work size  if layerScale != workScale
        if layerScale != workScale:
            pdb.gimp_layer_scale(lay4,workwidth,workheight,False)
            pdb.gimp_layer_set_offsets(lay4,0,0) # after scale, re-position layer.
# morph
        pdb.plug_in_gmic_qt(newImage, lay4,1,0,  # 1=input only active layer 
        '-v - -fx_morpho_v2 0,0,'+str(morphAmount)+','+'"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
# intensify inTens
        pdb.gimp_item_set_visible(lay4,True)
        Intensify_inTens(lay4,inTens)
        lay4 = pdb.gimp_image_merge_visible_layers(newImage,0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay4,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay4,0,0) # after scale, re-position layer.
# cut black
        pdb.gimp_image_select_color(newImage,0,lay4,black)
        pdb.gimp_edit_cut(lay4)
        pdb.gimp_selection_none(newImage)
# cutout subject leaving background only if selected
        if docutout:
            pdb.gimp_image_select_item(newImage, 0, oriSUB)
            pdb.gimp_edit_cut(lay4)
            pdb.gimp_selection_none(newImage)
# done - set
        lay4.mode = SCREEN_MODE
        lay4.opacity = 20.0
        lay4.name = layname
        pdb.gimp_item_set_visible(lay4,False)

#################################################################################################
####### Layer 5 - Kirlian A with Intensity ######################################################
#################################################################################################

    LayerString = '5x'+lay5str   
    Decode_A_Layer(LayerString)
    if makeLayer:
        out5 = True
        lay5 = oriSUB.copy()
        lay5.mode = NORMAL_MODE
        lay5.name = "Kirlian A" 
        lay5.opacity = 100.0 
        newImage.add_layer (lay5, 0)
        pdb.gimp_item_set_visible(lay5, False)
# special hardcoded scale down for better solidify workwidth*.2
        if solidifyOption > 0:
            pdb.gimp_layer_scale_full(lay5,int(workwidth*.2),int(workheight*.2), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay5,0,0) # after scale, re-position layer.
# solidify
            Solidify_A_Layer(solidifyOption,lay5)
# enhance option
        if boost == 1 or boost == 4:    #boost =1 desat =2 neither = 0
            pdb.plug_in_gmic_qt(newImage, lay5,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0")
        if boost == 2: 
            pdb.gimp_desaturate_full(lay5,2)
        if boost == 3 or boost == 4: 
            pdb.plug_in_colortoalpha(newImage, lay5, white)
# scale with layerScale from LayerString
        if layerScale != workScale:
            pdb.gimp_layer_scale_full(lay5,(workwidth*layerScale),(workheight*layerScale), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay5,0,0) # after scale, re-position layer.
#######
# special hardcoded scale for squiggle in layer 5
#        pdb.gimp_layer_scale_full(lay5,int(workwidth*.8),int(workheight*.8), True,3) # True = local origin, 3=Lanczos
#        pdb.gimp_layer_set_offsets(lay5,0,0) # after scale, re-position layer.
# squiggle at 80% worksize
#######
        pdb.plug_in_gmic_qt(newImage, lay5,1,0,  # 1=input active layer   ",1.80,0,0.5,0,0,0,2.5,0.2,0.4,12,1,1,0")
        "-v - -fx_Squiggly "+str(squiggleNoise)+","+str(segmentLength)+",1.8,0,0.5,0,0,0,3,0.2,0.4,12,1,1,0")
# scale to worksize for morph == different by design.
        pdb.gimp_layer_scale_full(lay5,int(workwidth),int(workheight), True,3) # True = local origin, 3=Lanczos
        pdb.gimp_layer_set_offsets(lay5,0,0) # after scale, re-position layer.
# morph at worksize
        pdb.plug_in_gmic_qt(newImage, lay5,1,0,  # 1=input only active layer, 0=output in place
        '-v - -fx_morpho_v2 0,0,'+str(morphAmount)+','+'"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
# intensify inTens
        pdb.gimp_item_set_visible(lay5,True)
        Intensify_inTens(lay5,inTens)
        lay5 = pdb.gimp_image_merge_visible_layers(newImage,0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay5,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay5,0,0) # after scale, re-position layer.
# cut black
        pdb.gimp_image_select_color(newImage,0,lay5,black)
        pdb.gimp_edit_cut(lay5)
        pdb.gimp_selection_none(newImage)
####### split into object and background layers  
        lay5bg = lay5.copy()
        lay5bg.mode = NORMAL_MODE
        lay5bg.name = "Kirlian A BG" 
        lay5bg.opacity = 100.0 
        newImage.add_layer (lay5bg, 0)
        pdb.gimp_item_set_visible(lay5bg, False)            
        pdb.gimp_image_select_item(newImage, 0, oriSUB)
        pdb.gimp_edit_cut(lay5bg)
        pdb.gimp_selection_invert(newImage)
        pdb.gimp_edit_cut(lay5)
        lay5.name = "Kirlian A Subject"
        pdb.gimp_selection_none(newImage)  
# done - set
        lay5.mode = SCREEN_MODE
        lay5.opacity = 35.0
        pdb.gimp_item_set_visible(lay5,False)
        lay5bg.mode = SCREEN_MODE
        lay5bg.opacity = 35.0
        pdb.gimp_item_set_visible(lay5bg,False)
#################################################################################################
####### Layer 6  Kirlian B with Intensity #######################################################
#################################################################################################

    LayerString = '6x'+lay6str
    Decode_A_Layer(LayerString)
    if makeLayer:
        out6 = True
        lay6 = oriSUB.copy()
        lay6.mode = NORMAL_MODE
        lay6.name = "Kirlian B" 
        lay6.opacity = 100.0 
        newImage.add_layer (lay6, 0)
        pdb.gimp_item_set_visible(lay6, False)
# special hardcoded scale down for better solidify workwidth*.2
        if solidifyOption > 0:
            pdb.gimp_layer_scale_full(lay6,int(workwidth*.2),int(workheight*.2), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay6,0,0) # after scale, re-position layer.
# solidify
            Solidify_A_Layer(solidifyOption,lay6)
# enhance option
        if boost == 1 or boost == 4:    #boost =1 desat =2 neither = 0
            pdb.plug_in_gmic_qt(newImage, lay6,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0")
        if boost == 2: 
            pdb.gimp_desaturate_full(lay6,2)
        if boost == 3 or boost == 4: 
            pdb.plug_in_colortoalpha(newImage, lay6, white)
# scale with layerScale from LayerString
        if layerScale != workScale:
            pdb.gimp_layer_scale_full(lay6,(workwidth*layerScale),(workheight*layerScale), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay6,0,0) # after scale, re-position layer.
#######
# special hardcoded scale for squiggle in layer 6
#        pdb.gimp_layer_scale_full(lay6,int(workwidth*.8),int(workheight*.8), True,3) # True = local origin, 3=Lanczos
#        pdb.gimp_layer_set_offsets(lay6,0,0) # after scale, re-position layer.
#######
# squiggle at 80% worksize
        pdb.plug_in_gmic_qt(newImage, lay6,1,0,  # 1=input only active layer 
        "-v - -fx_Squiggly "+str(squiggleNoise)+","+str(segmentLength)+",1.8,0,0.5,0,0,0,3,0.2,0.4,12,1,1,0")
# scale to worksize for morph == different by design.
        pdb.gimp_layer_scale_full(lay6,int(workwidth),int(workheight), True,3) # True = local origin, 3=Lanczos
        pdb.gimp_layer_set_offsets(lay6,0,0) # after scale, re-position layer.
# morph at worksize
        pdb.plug_in_gmic_qt(newImage, lay6,1,0,  # 1=input only active layer 
        '-v - -fx_morpho_v2 0,0,'+str(morphAmount)+','+'"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
# intensify inTens
        pdb.gimp_item_set_visible(lay6,True)
        Intensify_inTens(lay6,inTens)
        lay6 = pdb.gimp_image_merge_visible_layers(newImage,0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay6,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay6,0,0) # after scale, re-position layer.
# cut black
        pdb.gimp_image_select_color(newImage,0,lay6,black)
        pdb.gimp_edit_cut(lay6)
        pdb.gimp_selection_none(newImage)
####### split into object and background layers  
        lay6bg = lay6.copy()
        lay6bg.mode = NORMAL_MODE
        lay6bg.name = "Kirlian B BG" 
        lay6bg.opacity = 100.0 
        newImage.add_layer (lay6bg, 0)
        pdb.gimp_item_set_visible(lay6bg, False)            
        pdb.gimp_image_select_item(newImage, 0, oriSUB)
        pdb.gimp_edit_cut(lay6bg)
        pdb.gimp_selection_invert(newImage)
        pdb.gimp_edit_cut(lay6)
        lay6.name = "Kirlian B Subject"
        pdb.gimp_selection_none(newImage)        
# done - set
        lay6.mode = SCREEN_MODE
        lay6.opacity = 35.0
        pdb.gimp_item_set_visible(lay6,False)
        lay6bg.mode = SCREEN_MODE
        lay6bg.opacity = 35.0
        pdb.gimp_item_set_visible(lay6bg,False)
#################################################################################################
####### Layer 7 Kirlian C with Intensity ######$$$$$$$###########################################
#################################################################################################
    LayerString = '7x'+lay7str
    Decode_A_Layer(LayerString)
    if makeLayer:
        out7 = True
        lay7 = oriSUB.copy()
        lay7.mode = NORMAL_MODE
        lay7.name = "Kirlian C" 
        lay7.opacity = 100.0 
        newImage.add_layer (lay7, 0)
        pdb.gimp_item_set_visible(lay7, False)
# special hardcoded scale down for better solidify workwidth*.2
        if solidifyOption > 0:
            pdb.gimp_layer_scale_full(lay7,int(workwidth*.2),int(workheight*.2), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay7,0,0) # after scale, re-position layer.
# solidify
            Solidify_A_Layer(solidifyOption,lay7)
# enhance option
        if boost == 1 or boost == 4:    #boost =1 desat =2 neither = 0
            pdb.plug_in_gmic_qt(newImage, lay7,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0")
        if boost == 2: 
            pdb.gimp_desaturate_full(lay7,2)
        if boost == 3 or boost == 4: 
            pdb.plug_in_colortoalpha(newImage, lay7, white)
# scale with layerScale from LayerString
        if layerScale != workScale:
            pdb.gimp_layer_scale_full(lay7,(workwidth*layerScale),(workheight*layerScale), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay7,0,0) # after scale, re-position layer.
#######
# special hardcoded scale for squiggle in layer 7
#        pdb.gimp_layer_scale_full(lay7,int(workwidth*.8),int(workheight*.8), True,3) # True = local origin, 3=Lanczos
#        pdb.gimp_layer_set_offsets(lay7,0,0) # after scale, re-position layer.
#######
# squiggle at 80% worksize
        pdb.plug_in_gmic_qt(newImage, lay7,1,0,  # 1=input only active layer 
        "-v - -fx_Squiggly "+str(squiggleNoise)+","+str(segmentLength)+",1.8,0,0.5,0,0,0,3,0.2,0.4,12,1,1,0")
# scale to worksize for morph == different by design.
        pdb.gimp_layer_scale_full(lay7,int(workwidth),int(workheight), True,3) # True = local origin, 3=Lanczos
        pdb.gimp_layer_set_offsets(lay7,0,0) # after scale, re-position layer.
# morph at worksize
        pdb.plug_in_gmic_qt(newImage, lay7,1,0,  # 1=input only active layer 
        '-v - -fx_morpho_v2 0,0,'+str(morphAmount)+','+'"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
# intensify inTens
        pdb.gimp_item_set_visible(lay7,True)
        Intensify_inTens(lay7,inTens)
        lay7 = pdb.gimp_image_merge_visible_layers(newImage,0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay7,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay7,0,0) # after scale, re-position layer.
# cut black
        pdb.gimp_image_select_color(newImage,0,lay7,black)
        pdb.gimp_edit_cut(lay7)
        pdb.gimp_selection_none(newImage)
####### split into object and background layers  
        lay7bg = lay7.copy()
        lay7bg.mode = NORMAL_MODE
        lay7bg.name = "Kirlian C BG" 
        lay7bg.opacity = 100.0 
        newImage.add_layer (lay7bg, 0)
        pdb.gimp_item_set_visible(lay7bg, False)            
        pdb.gimp_image_select_item(newImage, 0, oriSUB)
        pdb.gimp_edit_cut(lay7bg)
        pdb.gimp_selection_invert(newImage)
        pdb.gimp_edit_cut(lay7)
        lay7.name = "Kirlian C Subject"
        pdb.gimp_selection_none(newImage)        
# done - set
        lay7.mode = SCREEN_MODE
        lay7.opacity = 35.0
        pdb.gimp_item_set_visible(lay7,False)
        lay7bg.mode = SCREEN_MODE
        lay7bg.opacity = 35.0
        pdb.gimp_item_set_visible(lay7bg,False)
####### raise subject layers to organize the layer stack
    if out5:
        pdb.gimp_image_raise_item_to_top(newImage,lay5)
    if out6:
        pdb.gimp_image_raise_item_to_top(newImage,lay6)
    if out7:
        pdb.gimp_image_raise_item_to_top(newImage,lay7)

#################################################################################################
####### Layer 8  Custom Layers ##################################################################
#################################################################################################
    LayerString = '8x'+lay8str
    Decode_A_Layer(LayerString)
    if makeLayer:
        out8 = True
        lay8 = oriSUB.copy()
        lay8.mode = NORMAL_MODE
        lay8.name = "My Layer" 
        lay8.opacity = 100.0 
        newImage.add_layer (lay8, 0)
        pdb.gimp_item_set_visible(lay8, False)
# special hardcoded scale down for better solidify workwidth*.2
        if solidifyOption > 0:
            pdb.gimp_layer_scale_full(lay8,int(workwidth*.2),int(workheight*.2), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay8,0,0) # after scale, re-position layer.
# solidify
            Solidify_A_Layer(solidifyOption,lay8)
# enhance option part 1
        if boost == 1 or boost == 4:    #boost =1 desat =2 neither = 0
            pdb.plug_in_gmic_qt(newImage, lay8,1,0,  # 1=input only active layer
            "-v - -fx_boost_fade 9.6,0")
        if boost == 2: 
            pdb.gimp_desaturate_full(lay8,2)

# scale with layerScale from LayerString
        if layerScale != workScale:
            pdb.gimp_layer_scale_full(lay8,(workwidth*layerScale),(workheight*layerScale), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay8,0,0) # after scale, re-position layer.
#######
# special hardcoded scale for squiggle in layer 10
#        pdb.gimp_layer_scale_full(lay8,int(workwidth*.8),int(workheight*.8), True,3) # True = local origin, 3=Lanczos
#        pdb.gimp_layer_set_offsets(lay8,0,0) # after scale, re-position layer.
#######
# squiggle at worksize * layerscale
        pdb.plug_in_gmic_qt(newImage, lay8,1,0,  # 1=input only active layer 
        "-v - -fx_Squiggly "+str(squiggleNoise)+","+str(segmentLength)+",1.8,0,0.5,0,0,0,3,0.2,0.4,12,1,1,0")
# scale with layerScale from LayerString
        if layerScale != workScale:
            pdb.gimp_layer_scale_full(lay8,(workwidth*layerScale),(workheight*layerScale), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay8,0,0) # after scale, re-position layer.
#######
# scale to worksize for morph == different by design.
#        pdb.gimp_layer_scale_full(lay8,int(workwidth),int(workheight), True,3) # True = local origin, 3=Lanczos
#        pdb.gimp_layer_set_offsets(lay8,0,0) # after scale, re-position layer.
#######
# morph at worksize * layerscale
        pdb.plug_in_gmic_qt(newImage, lay8,1,0,  # 1=input only active layer 
        '-v - -fx_morpho_v2 0,0,'+str(morphAmount)+','+'"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
# intensify inTens
        pdb.gimp_item_set_visible(lay8,True)
        Intensify_inTens(lay8,inTens)
        lay8 = pdb.gimp_image_merge_visible_layers(newImage,0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay8,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay8,0,0) # after scale, re-position layer.
# cut black
        pdb.gimp_image_select_color(newImage,0,lay8,black)
        pdb.gimp_edit_cut(lay8)
        pdb.gimp_selection_none(newImage)
# enhance option part 2
        if boost == 3 or boost == 4: 
            pdb.plug_in_colortoalpha(newImage, lay8, white)        
####### split into object and background layers  
        lay8bg = lay8.copy()
        lay8bg.mode = NORMAL_MODE
        lay8bg.name = "Custom BG" 
        lay8bg.opacity = 100.0 
        newImage.add_layer (lay8bg, 0)
        pdb.gimp_item_set_visible(lay8bg, False)            
        pdb.gimp_image_select_item(newImage, 0, oriSUB)
        pdb.gimp_edit_cut(lay8bg)
        pdb.gimp_selection_invert(newImage)
        pdb.gimp_edit_cut(lay8)
        lay8.name = "Custom Subject"
        pdb.gimp_selection_none(newImage)        
# done - set
        lay8.mode = SCREEN_MODE
        lay8.opacity = 35.0
        pdb.gimp_item_set_visible(lay8,False)
        lay8bg.mode = SCREEN_MODE
        lay8bg.opacity = 35.0
        pdb.gimp_item_set_visible(lay8bg,False)
####### move subject & background layers for stack continuity
        if out8:
            pdb.gimp_image_raise_item_to_top(newImage,lay8)
        if out5:
            pdb.gimp_image_lower_item(newImage, lay8bg)
        if out6:
            pdb.gimp_image_lower_item(newImage, lay8bg)
        if out7:
            pdb.gimp_image_lower_item(newImage, lay8bg)
##############################################
#        pdb.gimp_display_new (newImage)
#        pdb.gimp_displays_flush()
#        return()
##############################################

#################################################################################################
####### Layer 9  Smokey Subject Border  #########################################################
#################################################################################################
    if smokey !=0:
        #pdb.gimp_message('Create Layer 9 Yes')
        out9 = True
        lay9 = oriSUB.copy()
        lay9.mode = NORMAL_MODE
        lay9.name = "Light Smokey Border" 
        lay9.opacity = 100.0 
        newImage.add_layer(lay9, 0)
        pdb.gimp_item_set_visible(lay9,False)
##############################################
#        pdb.gimp_display_new (newImage)
#        pdb.gimp_displays_flush
#        return()
##############################################
# do whirl on subject copy 
        pdb.gimp_image_select_item(newImage, 0, lay9)
        pdb.plug_in_gmic_qt(newImage, lay9,1,0,  # 1=input only active layer
        '-v - -draw_whirl 20,0')
# do shrink feather and solidify x 2 
        if smokey < 5:
            smbw1 = 45
            smbw2 = 35
            shrinksel = 15
        elif smokey == 5:
            smbw1 = 30
            smbw2 = 20
            shrinksel = 10
        else: #smokey is 6 for thin
            smbw1 = 20
            smbw2 = 10
            shrinksel = 5
        pdb.gimp_selection_shrink(newImage, shrinksel) 
        pdb.gimp_selection_feather(newImage, smbw1) 
        pdb.plug_in_gmic_qt(newImage, lay9,1,0,  # 1=input only active layer
        '-v - -fx_solidify_td 75,1,20,4,0')
        pdb.gimp_selection_none(newImage)
        pdb.gimp_image_select_item(newImage, 0, lay9)
        pdb.gimp_selection_feather(newImage, smbw2) 
        pdb.plug_in_gmic_qt(newImage, lay9,1,0,  # 1=input only active layer
        '-v - -fx_solidify_td 75,1,20,4,0')
        pdb.gimp_curves_spline(lay9, 0, 4,(0,255,255,255))
        lay9a = lay9.copy()
        lay9a.mode = SCREEN_MODE
        lay9a.name = "Light Smokey Subject" 
        lay9a.opacity = 35.0
        newImage.add_layer(lay9a, 0)
# leave subject selection active and squiggle
        pdb.plug_in_gmic_qt(newImage, lay9,1,0,  # 1=input only active layer 
        '-v - -fx_Squiggly 20,15,1.41,0,0.37,0,0,0,4,1,0.68,12,1,1,0')
        pdb.gimp_image_set_active_layer(newImage, lay9)
# no morph on the smokey layers
# intensify inTens
        pdb.gimp_item_set_visible(lay9,True)
        Intensify_inTens(lay9,inTens)
        lay9 = pdb.gimp_image_merge_visible_layers(newImage,0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay9,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay9,0,0) # after scale, re-position layer.
# cut black
        pdb.gimp_image_select_color(newImage,0,lay9,black)
        pdb.gimp_edit_cut(lay9)
        pdb.gimp_selection_none(newImage)
# done 9 - set light smokey Light Smokey Border
        pdb.gimp_invert(lay9)
        pdb.gimp_curves_spline(lay9, 0, 4,(0,255,255,255))
        lay9.mode = SCREEN_MODE
        lay9.opacity = 20.0
        pdb.gimp_item_set_visible(lay9,False)
# add dark smokey border 
        lay9b = lay9.copy()
        lay9b.mode = NORMAL_MODE
        lay9b.name = "Dark Smokey Border"
        lay9b.opacity = 100.0
        newImage.add_layer(lay9b,0)
# invert colors for dark smokey border
        pdb.gimp_invert(lay9b)
        pdb.gimp_curves_spline(lay9b, 0, 4,(0,0,255,0))
# make two dark smokey layers for feathering effect of shadow
        if smokey > 3:
            lay9d = lay9b.copy()
            newImage.add_layer(lay9d,0)
            lay9d.mode = NORMAL_MODE
            lay9d.opacity = 100.0
            pdb.gimp_image_select_item(newImage, 0, oriSUB)
            pdb.gimp_selection_shrink(newImage, 3)
            pdb.gimp_selection_feather(newImage, 5)
            pdb.gimp_edit_cut(lay9d)
            pdb.gimp_selection_none(newImage)
            lay9d.mode = GRAIN_MERGE_MODE
            pdb.gimp_item_set_visible(lay9d,False)
###
            lay9e = lay9b.copy()
            newImage.add_layer(lay9e,0)
            lay9e.mode = NORMAL_MODE
            lay9e.opacity = 100.0
            pdb.gimp_image_select_item(newImage, 0, oriSUB)
            pdb.gimp_selection_feather(newImage, 5)
            pdb.gimp_edit_cut(lay9e)
            pdb.gimp_selection_none(newImage)
            lay9e.mode = GRAIN_MERGE_MODE
            pdb.gimp_item_set_visible(lay9e,False)
# add dark smokey subject 
        lay9c = lay9a.copy()
# done 9c - set dark smokey subject
        lay9c.mode = GRAIN_MERGE_MODE
        lay9c.name = "Dark Smokey Subject"
        lay9c.opacity = 20.0
        newImage.add_layer(lay9c,0)
        pdb.gimp_curves_spline(lay9c, 0, 4,(0,0,255,0))
        if smokey   == 4:
            lay9b.name = "Dark Smokey Thick 1"
            lay9d.name = "Dark Smokey Thick 2"
            lay9e.name = "Dark Smokey Thick 3"
        elif smokey == 5:
            lay9b.name = "Dark Smokey Med 1"
            lay9d.name = "Dark Smokey Med 2"
            lay9e.name = "Dark Smokey Med 3"
        elif smokey == 6:
            lay9b.name = "Dark Smokey Thin 1"
            lay9d.name = "Dark Smokey Thin 2"
            lay9e.name = "Dark Smokey Thin 3"

#################################################################################################
####### Layer 10 - Sparkle Layer - sometimes nice  Find a better way someday.... ################
#################################################################################################

    LayerString = '10x'+lay10str
    Decode_A_Layer(LayerString)
    if makeLayer:
        out10 = True
        lay10 = oriSUB.copy()
        lay10.mode = NORMAL_MODE
        lay10.name = "Sparkle" 
        lay10.opacity = 100.0 
        newImage.add_layer (lay10, 0)
        pdb.gimp_item_set_visible(lay10, False)
# special scale down for better solidify @ 20% 
        if solidifyOption > 0:
            pdb.gimp_layer_scale_full (lay10,int(workwidth*.2),int(workheight*.2), True,3) # True = local origin, 3=Lanczos
            pdb.gimp_layer_set_offsets(lay10,0,0) # after scale, re-position layer.
# solidify
            Solidify_A_Layer(solidifyOption,lay10)
# enhance option
        if boost == 1 or boost == 4:    #boost =1 desat =2 neither = 0
            pdb.plug_in_gmic_qt(newImage, lay10,1,0,  # 1=input only active layer
        "-v - -fx_boost_fade 9.6,0")
        if boost == 2: 
                pdb.gimp_desaturate_full(lay10,2)
        if boost == 3 or boost == 4: 
            pdb.plug_in_colortoalpha(newImage, lay10, white)
# scale for squiggle & morph
        pdb.gimp_layer_scale(lay10,(workwidth*layerScale),(workheight*layerScale),False)
        pdb.gimp_layer_set_offsets(lay10,0,0) # after scale, re-position layer.
# squiggle
        pdb.plug_in_gmic_qt(newImage, lay10,1,0,  # 1=input only active layer 
        "-v - -fx_Squiggly "+str(squiggleNoise)+","+str(segmentLength)+",1.8,0,0.5,0,0,0,3,0.2,0.4,12,1,1,0")
# morph
        pdb.plug_in_gmic_qt(newImage, lay10,1,0,  # 1=input only active layer 
        '-v - -fx_morpho_v2 0,0,'+str(morphAmount)+','+'"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
# scale back to worksize
        pdb.gimp_layer_scale(lay10,workwidth,workheight,False)
        pdb.gimp_image_resize_to_layers(newImage)
        pdb.gimp_layer_set_offsets(lay10,0,0) # after scale, re-position layer.
# intensify inTens
        pdb.gimp_item_set_visible(lay10,True)
        Intensify_inTens(lay10,inTens)
        lay10 = pdb.gimp_image_merge_visible_layers(newImage,0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay10,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay10,0,0) # after scale, re-position layer.
# cut black
        pdb.gimp_image_select_color(newImage,0,lay10,black)
        pdb.gimp_edit_cut(lay10)
        pdb.gimp_selection_none(newImage)
# done - set 
        lay10.mode = SCREEN_MODE
        lay10.opacity = 35.0
        pdb.gimp_item_set_visible(lay10,False)

#################################################################################################
####### Add Bubbles Background (button choice) ##################################################
#################################################################################################

    if addbub != 0: 
        out20 = True
        lay20= oriSUB.copy()
        lay20.mode = NORMAL_MODE
        lay20.name = "Bubbles" 
        lay20.opacity = 100.0 
        newImage.add_layer (lay20, 0)
        pdb.gimp_item_set_visible(lay20, False)
# special scale down for better solidify @ 20% 
        pdb.gimp_layer_scale_full (lay20,int(workwidth*.2),int(workheight*.2), True,3) # True = local origin, 3=Lanczos
        pdb.gimp_layer_set_offsets(lay20,0,0) # after scale, re-position layer.
# solidify hardcoded for this button option
        pdb.plug_in_gmic_qt(newImage, lay20, 1,0,  "-v - -fx_solidify_td 50,1,0,0,0")
# squiggle while small hardcoded for this button option
        pdb.plug_in_gmic_qt(newImage, lay20,1,0,  # 1=input only active layer 
        "-v - -fx_Squiggly "+str(squiggleNoise)+","+str(segmentLength)+",1.8,0,0.5,0,0,0,3,0.2,0.4,12,1,1,0")
# scale for morph hardcoded for this button option
        # hardcoded layerScale = 2 for this button option
        pdb.gimp_layer_scale(lay20,(workwidth*2),(workheight*2),False)
        pdb.gimp_layer_set_offsets(lay20,0,0) # after scale, re-position layer.
# morph hardcoded for this button option
        pdb.plug_in_gmic_qt(newImage, lay20,1,0,  # 1=input only active layer --
        '-v - -fx_morpho_v2 0,0,2,"1,0,1; 0,1,0; 1,0,1",0,0,0,1,0')
# scale back to work size if layerScale != workScale
        if 2 != workScale:
            pdb.gimp_layer_scale(lay20,workwidth,workheight,False)
            pdb.gimp_image_resize_to_layers(newImage)
            pdb.gimp_layer_set_offsets(lay20,0,0) # after scale, re-position layer.
# intensify custom
        pdb.gimp_item_set_visible(lay20,True)
        Intensify_Custom(lay20,40)
        lay20 = pdb.gimp_image_merge_visible_layers(newImage,0)
# multiply intensify custom
        pdb.gimp_item_set_visible(lay20,True)
        Intensify_Custom(lay20,5)
        lay20 = pdb.gimp_image_merge_visible_layers(newImage,0)
# scale to output size before cutting black
        pdb.gimp_layer_scale(lay20,outwidth,outheight,False)
        pdb.gimp_layer_set_offsets(lay20,0,0) # after scale, re-position layer.
# cut black
        pdb.gimp_image_select_color(newImage,0,lay20,black)
        pdb.gimp_edit_cut(lay20)
        pdb.gimp_selection_none(newImage)
# shrink cut for 'bubbles'  
        pdb.gimp_image_select_item(newImage,0,lay20)        
        pdb.gimp_selection_shrink(newImage,1)
        pdb.gimp_edit_cut(lay20)
        pdb.gimp_image_select_item(newImage,0,oriSUB)
        pdb.gimp_edit_cut(lay20)
        pdb.gimp_selection_none(newImage)
# add color to bubbles layer 
# process selection of bubbles layer 
        # selection 1 = Plain Bubbles 2 = desat 3 = gmic boost 4 = convo gmic boost
        if addbub == 2: # desaturate
            pdb.gimp_desaturate_full(lay20,2)
            lay20.name = "Bubbles Desaturated"
        if addbub == 3 or addbub == 4: # boost color
            pdb.gimp_item_set_visible(padLayer,True)
            pdb.plug_in_gmic_qt(newImage, lay20, 1,0, # 1=input only active layer --
            '-v - -fx_boost_fade 9.6,0') 
            lay20.name = "Bubbles Boosted"
        if addbub == 4:  # max boost with manual convolution.
            lay20x= lay20.copy()
            newImage.add_layer (lay20x, 0)
            pdb.gimp_item_set_visible(lay20x, True)
            lay20.mode  = SCREEN_MODE
            lay20x.mode = SCREEN_MODE
            lay20x.opacity = 100.0 
            lay20y= lay20x.copy()
            newImage.add_layer (lay20y, 0)
            lay20y.mode = SCREEN_MODE
            lay20y.opacity = 100.0
            pdb.gimp_item_set_visible(lay20y, True)
            pdb.gimp_item_set_visible(lay20x,True)
            pdb.gimp_item_set_visible(lay20, True)
            lay20x = pdb.gimp_image_merge_down(newImage,lay20y,0)
            lay20x.mode = SCREEN_MODE
            lay20 = pdb.gimp_image_merge_down(newImage,lay20x,0) 
            lay20.mode = SCREEN_MODE
            lay20x= lay20.copy()
            newImage.add_layer (lay20x, 0)
            lay20x.mode = SCREEN_MODE
            lay20x.opacity = 100.0
            lay20 = pdb.gimp_image_merge_down(newImage,lay20x,0)
            lay20.name = "Bubbles Max Boost"
        lay20.opacity = 35.0 
        lay20.mode  = SCREEN_MODE 
# cut subject from bubble background  
        pdb.gimp_image_select_item(newImage, 0, oriSUB)
        pdb.gimp_edit_cut(lay20)
        pdb.gimp_selection_none(newImage)
# done - set 
        lay20.mode = SCREEN_MODE
        lay20.opacity = 35.0
        pdb.gimp_item_set_visible(padLayer,False)
        pdb.gimp_item_set_visible(lay20,False)
# cut subject from bubble background   
        pdb.gimp_image_select_item(newImage, 0, oriSUB)
        pdb.gimp_edit_cut(lay20)
        pdb.gimp_selection_none(newImage)
# done - set 
        lay20.mode = SCREEN_MODE
        lay20.opacity = 35.0
        pdb.gimp_item_set_visible(lay20,False)

#################################################################################################
######## Add 2 top layers for extra color #######################################################
#################################################################################################
    lay21 = oriSUB.copy()
    lay21.mode = COLOR_MODE
    lay21.name = "Subject Color Layer 1"
    newImage.add_layer(lay21, 0)
    pdb.gimp_item_set_visible(lay21, False)
    
    lay22 = oriSUB.copy()
    lay22.mode = GRAIN_MERGE_MODE
    lay22.name = "GrainMerge/HardLight"
    newImage.add_layer(lay22, 0)
    pdb.gimp_item_set_visible(lay22, False)

#################################################################################################
####### oriSUB layer has always been at output size #############################################
#################################################################################################
####### always produce these layers #############################################################
#################################################################################################
    pdb.gimp_layer_scale_full(padLayer,outwidth,outheight, True,3)
    pdb.gimp_layer_set_offsets(padLayer,0,0)
    padLayer.opacity = 100.0
    pdb.gimp_layer_set_visible(padLayer,True)
    ##
    pdb.gimp_layer_scale_full(oriSUB,outwidth,outheight, True,3)
    pdb.gimp_layer_set_offsets(oriSUB,0,0)
    oriSUB.opacity = 20.0
    pdb.gimp_item_set_visible(oriSUB,False)  
    ##
    pdb.gimp_layer_scale_full(lay21,outwidth,outheight, True,3)
    pdb.gimp_layer_set_offsets(lay21,0,0)
    lay21.opacity = 100.0
    pdb.gimp_item_set_visible(lay21,True)
    ##
    pdb.gimp_layer_scale_full(lay22,outwidth,outheight, True,3)
    pdb.gimp_layer_set_offsets(lay22,0,0)
    lay22.opacity = 50.0
    pdb.gimp_item_set_visible(lay22,True)
#################################################################################################
####### if layers created give ##################################################################
####### final scale and set    ##################################################################
#################################################################################################
    if out1:
        pdb.gimp_layer_scale_full(lay1, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay1,0,0)
        lay1.mode = SCREEN_MODE
        lay1.opacity = 20.0 
        pdb.gimp_item_set_visible(lay1, False)
    if out1a: # Stitch Background
        pdb.gimp_layer_scale_full(lay1a,outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay1a,0,0)
        lay1a.opacity = 100.0
        pdb.gimp_item_set_visible(lay1a,True)
    if out2:
        pdb.gimp_layer_scale_full(lay2, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay2,0,0)
        lay2.opacity = 20.0
        pdb.gimp_item_set_visible(lay2,True)
    if out3:
        pdb.gimp_layer_scale_full(lay3, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay3,0,0)
        lay3.opacity = 20.0
        pdb.gimp_item_set_visible(lay3,True)
    if out4:
        pdb.gimp_layer_scale_full(lay4, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay4,0,0)
        lay4.opacity = 20.0
        pdb.gimp_item_set_visible(lay4,True)
    if out5: #kirlian A
        pdb.gimp_layer_scale_full(lay5, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay5,0,0)
        lay5.opacity = 35.0
        pdb.gimp_item_set_visible(lay5,True)
        ##
        pdb.gimp_layer_scale_full(lay5bg, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay5bg,0,0)
        lay5bg.opacity = 20.0
        pdb.gimp_item_set_visible(lay5bg,True)
    if out6: #kirlian B
        pdb.gimp_layer_scale_full(lay6, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay6,0,0)
        lay6.opacity = 35.0
        pdb.gimp_item_set_visible(lay6,True)
        ##
        pdb.gimp_layer_scale_full(lay6bg, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay6bg,0,0)
        lay6bg.opacity = 20.0
        pdb.gimp_item_set_visible(lay6bg,True)
    if out7: #kirlian C
        pdb.gimp_layer_scale_full(lay7, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay7,0,0)
        lay7.opacity = 35.0
        pdb.gimp_item_set_visible(lay7,True)
        ##
        pdb.gimp_layer_scale_full(lay7bg, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay7bg,0,0)
        lay7bg.opacity = 20.0
        pdb.gimp_item_set_visible(lay7bg,True)
    if out8: #Custom Kirlian 
        pdb.gimp_layer_scale_full(lay8,outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay8,0,0)
        pdb.gimp_item_set_visible(lay8,True)
        ##
        pdb.gimp_layer_scale_full(lay8bg,outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay8bg,0,0)
        lay8bg.opacity = 20.0
        pdb.gimp_item_set_visible(lay8bg,True)
    if out9:  # Smokey Border layers 
        # lay9 = light smokey border
        pdb.gimp_layer_scale_full(lay9, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay9,0,0)
        lay9.opacity = 50.0
        pdb.gimp_item_set_visible(lay9,False)
        ## lay9a = light smokey subject
        pdb.gimp_layer_scale_full(lay9a, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay9a,0,0)
        lay9a.opacity = 20.0
        pdb.gimp_item_set_visible(lay9a,False)
        ## lay9b = dark smokey border
        pdb.gimp_layer_scale_full(lay9b, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay9b,0,0)
        lay9b.opacity = 40.0
        pdb.gimp_item_set_visible(lay9b,False)
        ## lay9c = dark smokey subject 1
        pdb.gimp_layer_scale_full(lay9c, outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay9c,0,0)
        lay9c.opacity = 40.0
        pdb.gimp_item_set_visible(lay9c,False)
        if smokey > 3:
            ## lay9d = dark smokey border style 2
            pdb.gimp_layer_scale_full(lay9d, outwidth,outheight, True,3)
            pdb.gimp_layer_set_offsets(lay9d,0,0)
            lay9d.opacity = 60.0
            pdb.gimp_item_set_visible(lay9d,False)
            ## lay9e = dark smokey border style 3
            pdb.gimp_layer_scale_full(lay9e, outwidth,outheight, True,3)
            pdb.gimp_layer_set_offsets(lay9e,0,0)
            lay9e.opacity = 100.0
            pdb.gimp_item_set_visible(lay9e,False)
        if smokey > 1:
            if smokey == 2:  # delete darks
                pdb.gimp_image_remove_layer(newImage, lay9b)
                pdb.gimp_image_remove_layer(newImage, lay9c)
            if smokey == 3:  # delete lights
                pdb.gimp_image_remove_layer(newImage, lay9)
                pdb.gimp_image_remove_layer(newImage, lay9a)
    if out10: # Sparkle Layer (intermittant but sometimes interesting)
        pdb.gimp_layer_scale_full(lay10,outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay10,0,0)
        lay10.opacity = 50.0
        pdb.gimp_item_set_visible(lay10,True)
    if out20: # Bubble Background
        pdb.gimp_layer_scale_full(lay20,outwidth,outheight, True,3)
        pdb.gimp_layer_set_offsets(lay20,0,0)
        lay20.opacity = 35.0
        pdb.gimp_item_set_visible(lay20,True)

    pdb.gimp_image_resize_to_layers(newImage)        

    # Clean Up
    pdb.gimp_display_new (newImage)
    pdb.gimp_displays_flush()
   

    pdb.gimp_context_pop()
    pdb.gimp_context_set_foreground(currFG)
    pdb.gimp_context_set_background(currBG)
    
    return()    

register(
    "BA_SpiderPaint_v2c_qt2",
    "BA_SpiderPaint_v2c_qt2 Layer Commands delimited by X \nMakeLayer Y/F/N x Plain,Boost,DeSat,noWhite 0,1,2,3 x \nSolidify 0-35 x Scale% 0-200 x \nNoise .00-20 x SegLen .50-15 x Morph 0-10",
    "Needs GMIC QT 2.0",
    "animicule@gimpchat.com", 
    "Brian Andersen ", 
    "April 2017",
    "BA_SpiderPaint v2c GMic QT 2",
    "RGBA",
    [
        (PF_IMAGE,      "image"      , "Input image                                 ", None),   #Y x N x 4 x50x2x 15 x 2
        (PF_DRAWABLE,   "drawable"   , "Input drawable                              ", None),
        (PF_ADJUSTMENT, "worklen"    , "Process size (longest side)                 ",  2000,(   0, 9600, 300)),
        (PF_SLIDER,     "inTens"     , "Intensity (at 100% layer opacity)           ",   30, (   4,   40,   1)),
        (PF_STRING,     "lay1str"    , " 1 Razorsplit Background with Intensity     ", "N x 1 x  2 x 50 x 1   x15   x 0"),
        (PF_STRING,     "lay2str"    , " 2 Low Intensity BG or (F)ull-image         ", "Y X 4 X 10 x 60 x  .01x  .5 x 2"),
        (PF_STRING,     "lay3str"    , " 3 Background or (F)ull-image Intense       ", "F x 4 x 35 x 60 x  .01x 1   x 2"),
        (PF_STRING,     "lay4str"    , " 4 Background or (F)ull-image Wide          ", "Y x 4 x 15 x 60 x  .01x 2   x 2"),
        (PF_STRING,     "lay5str"    , " 5 Kirlian A Layers with Intensity          ", "Y x 4 x 24 x 80 x 1.5 x 1.5 x 2"),
        (PF_STRING,     "lay6str"    , " 6 Kirlian B Layers with Intensity          ", "Y x 1 x 32 x 80 x 2   x 3   x 2"),
        (PF_STRING,     "lay7str"    , " 7 Kirlian C Layers with Intensity          ", "Y x 0 x 32 x100 x 3   x 5   x 2"),
        (PF_STRING,     "lay8str"    , " 8 Custom Layer                             ", "Y x 3 x 17 x100 x 3   x 5   x 2"),
        (PF_OPTION,     "smokey"     , " 9 Add Smokey Border Layers                 ", 4, ("None", "All", "Light", "Dark", "Thick", "Medium", "Thin")),
        (PF_STRING,     "lay10str"   , "10 Sparkle Layer (may need morph adjustment)", "Y x 3 x 10 x 150 x 3  x 2   x 4"), 
        (PF_OPTION,     "stitch"     , "Add Stitched Background (select option)     ", 9, ("None", "Stitched Full", "Stitched Full Boosted", "Stitched Full No white", "Stitched Full Boosted No White", "Stitched Cut", "Stitched Cut Boosted", "Stitched Cut No white", "Stitched Cut Boosted No White", "Stitched Exaggerated")),
        (PF_OPTION,     "addbub"     , "Add Bubble Background                       ", 0, ("None", "Plain", "Desat", "Boosted", "Max Boost")),
    ],
    [],
    BA_SpiderPaint_v2c_qt2,
    menu="<Image>/Brian/",
    )

main()
